@@ -57,12 +57,12 @@ summary.MixedContContIT <- function(object, ..., Object){
   colnames(means_table) <- c("Control Treatment", "Experimental treatment")
   rownames(means_table) <- c("Surrogate", "True endpoint")
   cat("\n\nMean surrogate and true endpoint values in each treatment group: \n\n")
-  print(format(round(data.frame(means_table), 4), nsmall = 4))
+  print(format(round(data.frame(means_table, stringsAsFactors = TRUE), 4), nsmall = 4))
   Var_table <- rbind(tapply(Object$Data.Analyze$Surr, list(Object$Data.Analyze$Treat), var), tapply(Object$Data.Analyze$True, list(Object$Data.Analyze$Treat), var))
   colnames(Var_table) <- c("Control Treatment", "Experimental treatment")
   rownames(Var_table) <- c("Surrogate", "True endpoint")
   cat("\n\nVar surrogate and true endpoint values in each treatment group: \n\n")
-  print(format(round(data.frame(Var_table), 4), nsmall = 4))
+  print(format(round(data.frame(Var_table, stringsAsFactors = TRUE), 4), nsmall = 4))
   
   cat("\n\nCorrelations between the true and surrogate endpoints in the control (r_T0S0)")
   cat("\nand the experimental treatment groups (r_T1S1):\n\n")
