@@ -1,9 +1,11 @@
-clayton_loglik <- function(para, X, Y, d1, d2, k = 2, knotsx, knotsy){
-  #k is the number of knots in the model, this determines the length of para
-  gammax <- para[1:(k + 2)]
-  gammay <- para[(k + 3):(2*(k + 2))]
+clayton_loglik <- function(para, X, Y, d1, d2, knotsx, knotsy, sum_observations){
+  #k is the number of knots in the model, this determines the length of para.
+  kx = length(knotsx) - 2
+  ky = length(knotsy) - 2
+  gammax <- para[1:(kx + 2)]
+  gammay <- para[(kx + 3):(kx + ky + 4)]
   #last value in para is the association parameter
-  theta <- para[2*(k + 2) + 1]
+  theta <- para[kx + ky + 5]
 
   #survival probabilities
   u = flexsurv::psurvspline(q = X, gamma = gammax, knots = knotsx, lower.tail = FALSE)
@@ -19,17 +21,22 @@ clayton_loglik <- function(para, X, Y, d1, d2, k = 2, knotsx, knotsy){
   part3 <- ifelse((1-d1)*d2==1, (theta+1)*log(C) - (theta+1)*log(v) + log(dv),0) #terminal event only
   part4 <- ifelse((1-d1)*(1-d2)==1,log(C),0) #both events censored
 
-  loglik <- sum(part1+part2+part3+part4)
+  loglik = part1+part2+part3+part4
+  if (sum_observations){
+    loglik <- sum(loglik)
+  }
 
   return(loglik)
 }
 
-frank_loglik <- function(para, X, Y, d1, d2, k = 2, knotsx, knotsy){
-  #k is the number of knots in the model, this determines the length of para
-  gammax <- para[1:(k + 2)]
-  gammay <- para[(k + 3):(2*(k + 2))]
+frank_loglik <- function(para, X, Y, d1, d2, knotsx, knotsy, sum_observations){
+  #k is the number of knots in the model, this determines the length of para.
+  kx = length(knotsx) - 2
+  ky = length(knotsy) - 2
+  gammax <- para[1:(kx + 2)]
+  gammay <- para[(kx + 3):(kx + ky + 4)]
   #last value in para is the association parameter
-  theta <- para[2*(k + 2) + 1]
+  theta <- para[kx + ky + 5]
 
   #survival probabilities
   u = flexsurv::psurvspline(q = X, gamma = gammax, knots = knotsx, lower.tail = FALSE)
@@ -46,17 +53,22 @@ frank_loglik <- function(para, X, Y, d1, d2, k = 2, knotsx, knotsy){
   part3 <- ifelse(((1-d1)*(d2))==1,(log((1-exp(theta*C))/(1-exp(theta*v)))+log(dv)),0)
   part4 <- ifelse(((1-d1)*(1-d2))==1,log(C),0)
 
-  loglik <- sum(part1+part2+part3+part4)
+  loglik = part1+part2+part3+part4
+  if (sum_observations){
+    loglik <- sum(loglik)
+  }
 
   return(loglik)
 }
 
-gumbel_loglik <- function(para, X, Y, d1, d2, k = 2, knotsx, knotsy){
-  #k is the number of knots in the model, this determines the length of para
-  gammax <- para[1:(k + 2)]
-  gammay <- para[(k + 3):(2*(k + 2))]
+gumbel_loglik <- function(para, X, Y, d1, d2, knotsx, knotsy, sum_observations){
+  #k is the number of knots in the model, this determines the length of para.
+  kx = length(knotsx) - 2
+  ky = length(knotsy) - 2
+  gammax <- para[1:(kx + 2)]
+  gammay <- para[(kx + 3):(kx + ky + 4)]
   #last value in para is the association parameter
-  theta <- para[2*(k + 2) + 1]
+  theta <- para[kx + ky + 5]
 
   #survival probabilities
   u = flexsurv::psurvspline(q = X, gamma = gammax, knots = knotsx, lower.tail = FALSE)
@@ -75,18 +87,26 @@ gumbel_loglik <- function(para, X, Y, d1, d2, k = 2, knotsx, knotsy){
   part3 <- ifelse(((1-d1)*(d2))==1,(log(C)+(theta-1)*log(-log(v))-log(v)-(theta-1)*log(-log(C))+log(dv)),0)
   part4 <- ifelse(((1-d1)*(1-d2))==1,log(C),0)
 
-  loglik <- sum(part1+part2+part3+part4)
+  loglik = part1+part2+part3+part4
+  if (sum_observations){
+    loglik <- sum(loglik)
+  }
 
   return(loglik)
 }
 
 #' @importFrom stats pnorm qnorm
-normal_loglik <- function(para, X, Y, d1, d2, k = 2, knotsx, knotsy){
-  #k is the number of knots in the model, this determines the length of para
-  gammax <- para[1:(k + 2)]
-  gammay <- para[(k + 3):(2*(k + 2))]
+normal_loglik <- function(para, X, Y, d1, d2, knotsx, knotsy, sum_observations){
+  requireNamespace("mvtnorm")
+  #k is the number of knots in the model, this determines the length of para.
+  kx = length(knotsx) - 2
+  ky = length(knotsy) - 2
+  gammax <- para[1:(kx + 2)]
+  gammay <- para[(kx + 3):(kx + ky + 4)]
+  #last value in para is the association parameter
+  theta <- para[kx + ky + 5]
   # Last value in para is rho. We use the inverse Fisher transformation.
-  rho <- (exp(2 * para[2*(k + 2) + 1]) - 1)/(exp(2 * para[2*(k + 2) + 1]) + 1)
+  rho <- (exp(2 * theta) - 1)/(exp(2 * theta) + 1)
 
   df.1 <- d1 & d2     #case part 1
   df.2 <- d1 & (!d2)  #case part 2
@@ -211,7 +231,11 @@ normal_loglik <- function(para, X, Y, d1, d2, k = 2, knotsx, knotsy){
     )), 1, normal_cdf, cov_matrix
   ))), 0)
 
-  loglik <- (part1+part2+part3+part4)
+  loglik = part1+part2+part3+part4
+  if (sum_observations){
+    loglik <- sum(loglik)
+  }
+
   return(loglik)
 }
 
